@@ -20,9 +20,9 @@
 #' @param level  numeric; the confidence level of the confidence interval in
 #' the bootstrap test.
 #' @param type  a character string specifying the type of confidence interval
-#' to be computed in the bootstrap test.  Possible values are \code{"bca"} for
-#' the bias-corrected and accelerated (BCa) bootstrap, or \code{"perc"} for the
-#' percentile bootstrap.
+#' to be computed in the bootstrap test.  Possible values are \code{"perc"}
+#' for the percentile bootstrap, or \code{"bca"} for the bias-corrected and
+#' accelerated (BCa) bootstrap.
 #' @param contrast  a logical indicating whether to compute pairwise contrasts
 #' of the indirect effects.  This can also be a character string, with
 #' \code{"estimates"} for computing the pairwise differences of the indirect
@@ -41,9 +41,14 @@
 #' @return An object of the same class as \code{object} with updated test
 #' results (see \code{\link{test_mediation}()}).
 #'
-#' @note From version 0.9.0 onwards, the behavior of this function changed.
-#' For arguments that are not supplied, the corresponding values of
-#' \code{object} are now used as defaults.
+#' @note
+#' From version 0.9.0 onwards, the behavior of this function changed. For
+#' arguments that are not supplied, the corresponding values of \code{object}
+#' are now used as defaults.
+#'
+#' Since version 1.1.0, bias-corrected and accelerated (BCa) bootstrap
+#' confidence intervals are no longer recommended, and the option
+#' \code{type = "bca"} may disappear in the future.
 #'
 #' @author Andreas Alfons
 #'
@@ -54,13 +59,16 @@
 #'
 #' # run fast-and-robust bootstrap test
 #' boot <- test_mediation(BSG2014,
-#'                        x = "ValueDiversity",
-#'                        y = "TeamCommitment",
-#'                        m = "TaskConflict")
+#'                        x = "SharedLeadership",
+#'                        y = "TeamPerformance",
+#'                        m = c("ProceduralJustice",
+#'                              "InteractionalJustice"),
+#'                        covariates = c("AgeDiversity",
+#'                                       "GenderDiversity"))
 #' summary(boot)
 #'
-#' # now compute 97.5% confidence interval
-#' retest(boot, level = 0.975)
+#' # now include comparison of indirect effects
+#' retest(boot, contrast = "estimates")
 #'
 #' @keywords multivariate
 #'
@@ -77,7 +85,7 @@ retest.boot_test_mediation <- function(object, alternative, level,
                                        type, contrast, ...) {
   # initializations
   defaults <- list(alternative = c("twosided", "less", "greater"),
-                   type = c("bca", "perc"),
+                   type = c("perc", "bca"),
                    contrast = c("estimates", "absolute"))
   fit <- object$fit
   # check alternative hypothesis
