@@ -127,14 +127,17 @@
 #' \code{TRUE}).  This is only relevant if \code{method = "regression"} and
 #' \code{robust = FALSE}.
 #' @param control  a list of tuning parameters for the corresponding robust
-#' method.  For robust regression (\code{method = "regression"}, and
-#' \code{robust = TRUE} or \code{robust = "MM"}), a list of tuning
-#' parameters for \code{\link[robustbase]{lmrob}()} as generated by
-#' \code{\link{reg_control}()}.  For winsorized covariance matrix estimation
-#' (\code{method = "covariance"} and \code{robust = TRUE}), a list of tuning
-#' parameters for \code{\link{cov_Huber}()} as generated by
-#' \code{\link{cov_control}()}.  No tuning parameters are necessary for median
-#' regression (\code{method = "regression"} and \code{robust = "median"}).
+#' method.  For the robust MM-estimator of regression
+#' (\code{method = "regression"}, and \code{robust = TRUE} or
+#' \code{robust = "MM"}), a list of tuning parameters for
+#' \code{\link[robustbase]{lmrob}()} as generated by
+#' \code{\link{MM_reg_control}()}.  For median regression
+#' (\code{method = "regression"}, and \code{robust = "median"}), a list of
+#' tuning parameters for \code{\link[quantreg]{rq}()} as generated by
+#' \code{\link{median_reg_control}()}.  For winsorized covariance matrix
+#' estimation (\code{method = "covariance"} and \code{robust = TRUE}), a list
+#' of tuning parameters for \code{\link{cov_Huber}()} as generated by
+#' \code{\link{cov_control}()}.
 #' @param \dots  additional arguments to be passed down.  For the bootstrap
 #' tests, those can be used to specify arguments of \code{\link[boot]{boot}()},
 #' for example for parallel computing.
@@ -504,7 +507,7 @@ boot_test_mediation.reg_fit_mediation <- function(fit,
     fit_ymx <- fit$fit_ymx
     # extract control object from robust regressions
     # (necessary to compute correction matrices)
-    psi_control <- get_psi_control(fit_ymx)  # the same for all model fits
+    psi_control <- get_psi_control(fit)
 
     # extract (square root of) robustness weights and combine data
     if (p_m == 1L) w_m <- sqrt(weights(fit_mx, type = "robustness"))
@@ -666,9 +669,11 @@ boot_test_mediation.reg_fit_mediation <- function(fit,
 
   } else if (robust == "median") {
 
+    # extract algorithm object from model fit
+    control <- fit$control
     # define function for standard bootstrap with median regression
     # (the fast-and-robust bootstrap does not work for median regression)
-    median_bootstrap <- function(z, i) {
+    median_bootstrap <- function(z, i, control) {
       # extract bootstrap sample from the data
       z_i <- z[i, , drop = FALSE]
       # compute coefficients from regressions m ~ x + covariates
@@ -677,7 +682,8 @@ boot_test_mediation.reg_fit_mediation <- function(fit,
         coef_m_i <- mapply(function(current_j_m, current_j_mx) {
           mx_i <- z_i[, current_j_mx]
           m_i <- z_i[, current_j_m]
-          unname(rq.fit(mx_i, m_i, tau = 0.5)$coefficients)
+          unname(rq.fit(mx_i, m_i, tau = 0.5,
+                        method = control$method)$coefficients)
         }, current_j_m = j_m, current_j_mx = j_mx,
         SIMPLIFY = FALSE, USE.NAMES = FALSE)
         # make sure coefficients are vectors
@@ -688,23 +694,26 @@ boot_test_mediation.reg_fit_mediation <- function(fit,
         m_i <- z_i[, j_m]
         # compute coefficients
         if (p_m == 1L) {
-          coef_m_i <- unname(rq.fit(x_i, m_i, tau = 0.5)$coefficients)
+          coef_m_i <- unname(rq.fit(x_i, m_i, tau = 0.5,
+                                    method = control$method)$coefficients)
         } else {
           coef_m_i <- unname(apply(m_i, 2, function(current_m_i) {
-            rq.fit(x_i, current_m_i, tau = 0.5)$coefficients
+            rq.fit(x_i, current_m_i, tau = 0.5,
+                   method = control$method)$coefficients
           }))
         }
       }
       # compute coefficients from regression y ~ m + x + covariates
       mx_i <- z_i[, c(1L, j_m, j_x, j_covariates)]
       y_i <- z_i[, j_y]
-      coef_y_i <- unname(rq.fit(mx_i, y_i, tau = 0.5)$coefficients)
+      coef_y_i <- unname(rq.fit(mx_i, y_i, tau = 0.5,
+                                method = control$method)$coefficients)
       # return coefficients
       c(coef_m_i, coef_y_i)
     }
 
     # perform standard bootstrap with median regression
-    bootstrap <- local_boot(z, median_bootstrap, R = R, ...)
+    bootstrap <- local_boot(z, median_bootstrap, R = R, control = control, ...)
     R <- nrow(bootstrap$t)  # make sure that number of replicates is correct
 
   } else if (family == "gaussian") {
